@@ -55,6 +55,7 @@ check_keys(const int32_t attrib_list[])
             case WAFFLE_CONTEXT_FORWARD_COMPATIBLE:
             case WAFFLE_CONTEXT_DEBUG:
             case WAFFLE_CONTEXT_ROBUST_ACCESS:
+            case WAFFLE_CONTEXT_LOSE_CONTEXT_ON_RESET:
             case WAFFLE_RED_SIZE:
             case WAFFLE_GREEN_SIZE:
             case WAFFLE_BLUE_SIZE:
@@ -305,7 +306,7 @@ set_misc_defaults(struct wcore_config_attrs *attrs)
     attrs->samples              = 0;
     attrs->double_buffered      = true;
     attrs->accum_buffer         = false;
-
+    attrs->lose_context_on_reset = false;
     return true;
 }
 
@@ -369,6 +370,8 @@ parse_misc(struct wcore_config_attrs *attrs,
 
             CASE_BOOL(WAFFLE_CONTEXT_DEBUG, context_debug, false);
             CASE_BOOL(WAFFLE_CONTEXT_ROBUST_ACCESS, context_robust, false);
+            CASE_BOOL(WAFFLE_CONTEXT_LOSE_CONTEXT_ON_RESET,
+                      lose_context_on_reset, false);
             CASE_BOOL(WAFFLE_SAMPLE_BUFFERS, sample_buffers, DEFAULT_SAMPLE_BUFFERS);
             CASE_BOOL(WAFFLE_DOUBLE_BUFFERED, double_buffered, DEFAULT_DOUBLE_BUFFERED);
             CASE_BOOL(WAFFLE_ACCUM_BUFFER, accum_buffer, DEFAULT_ACCUM_BUFFER);
