@@ -40,7 +40,7 @@ struct test_state_wcore_config_attrs {
     struct wcore_config_attrs expect_attrs;
 };
 
-static void
+static int
 setup(void **state) {
     static const struct wcore_config_attrs default_attrs = {
         // There is no default context api, so arbitrarily choose OpenGL. The
@@ -71,20 +71,26 @@ setup(void **state) {
 
     struct test_state_wcore_config_attrs *ts;
 
-    wcore_error_reset();
+    ts = calloc(1, sizeof(*ts));
+    if (!ts)
+        return -1;
 
-    *state = ts = calloc(1, sizeof(*ts));
+    *state = ts;
+
+    wcore_error_reset();
 
     // Fill actual_attrs with canaries.
     memset(&ts->actual_attrs, 0x99, sizeof(ts->actual_attrs));
 
     // Set expect_attrs to defaults.
     memcpy(&ts->expect_attrs, &default_attrs, sizeof(ts->expect_attrs));
+    return 0;
 }
 
-static void
+static int
 teardown(void **state) {
     free(*state);
+    return 0;
 }
 
 static void
@@ -444,21 +450,6 @@ test_wcore_config_attrs_gles11(void **state) {
     assert_int_equal(ts->actual_attrs.context_minor_version, 1);
 }
 
-static void
-test_wcore_config_attrs_gles12_is_bad(void **state) {
-    struct test_state_wcore_config_attrs *ts = *state;
-
-    const int32_t attrib_list[] = {
-        WAFFLE_CONTEXT_API,             WAFFLE_CONTEXT_OPENGL_ES1,
-        WAFFLE_CONTEXT_MAJOR_VERSION,   1,
-        WAFFLE_CONTEXT_MINOR_VERSION,   2,
-        0,
-    };
-
-    assert_false(wcore_config_attrs_parse(attrib_list, &ts->actual_attrs));
-    assert_int_equal(wcore_error_get_code(), WAFFLE_ERROR_BAD_ATTRIBUTE);
-}
-
 static void
 test_wcore_config_attrs_gles20(void **state) {
     struct test_state_wcore_config_attrs *ts = *state;
@@ -491,21 +482,6 @@ test_wcore_config_attrs_gles21(void **state) {
     assert_int_equal(ts->actual_attrs.context_minor_version, 1);
 }
 
-static void
-test_wcore_config_attrs_gles2_with_version_30(void **state) {
-    struct test_state_wcore_config_attrs *ts = *state;
-
-    const int32_t attrib_list[] = {
-        WAFFLE_CONTEXT_API,             WAFFLE_CONTEXT_OPENGL_ES2,
-        WAFFLE_CONTEXT_MAJOR_VERSION,   3,
-        WAFFLE_CONTEXT_MINOR_VERSION,   0,
-        0,
-    };
-
-    assert_false(wcore_config_attrs_parse(attrib_list, &ts->actual_attrs));
-    assert_int_equal(wcore_error_get_code(), WAFFLE_ERROR_BAD_ATTRIBUTE);
-}
-
 static void
 test_wcore_config_attrs_gles30(void **state) {
     struct test_state_wcore_config_attrs *ts = *state;
@@ -538,36 +514,6 @@ test_wcore_config_attrs_gles31(void **state) {
     assert_int_equal(ts->actual_attrs.context_minor_version, 1);
 }
 
-static void
-test_wcore_config_attrs_gles3_with_version_20(void **state) {
-    struct test_state_wcore_config_attrs *ts = *state;
-
-    const int32_t attrib_list[] = {
-        WAFFLE_CONTEXT_API,             WAFFLE_CONTEXT_OPENGL_ES3,
-        WAFFLE_CONTEXT_MAJOR_VERSION,   2,
-        WAFFLE_CONTEXT_MINOR_VERSION,   0,
-        0,
-    };
-
-    assert_false(wcore_config_attrs_parse(attrib_list, &ts->actual_attrs));
-    assert_int_equal(wcore_error_get_code(), WAFFLE_ERROR_BAD_ATTRIBUTE);
-}
-
-static void
-test_wcore_config_attrs_gles3_with_version_40(void **state) {
-    struct test_state_wcore_config_attrs *ts = *state;
-
-    const int32_t attrib_list[] = {
-        WAFFLE_CONTEXT_API,             WAFFLE_CONTEXT_OPENGL_ES3,
-        WAFFLE_CONTEXT_MAJOR_VERSION,   4,
-        WAFFLE_CONTEXT_MINOR_VERSION,   0,
-        0,
-    };
-
-    assert_false(wcore_config_attrs_parse(attrib_list, &ts->actual_attrs));
-    assert_int_equal(wcore_error_get_code(), WAFFLE_ERROR_BAD_ATTRIBUTE);
-}
-
 static void
 test_wcore_config_attrs_color_buffer_size(void **state) {
     struct test_state_wcore_config_attrs *ts = *state;
@@ -1145,8 +1091,8 @@ test_wcore_config_attrs_debug_gles3(void **state) {
 
 int
 main(void) {
-    const UnitTest tests[] = {
-        #define unit_test_make(name) unit_test_setup_teardown(name, setup, teardown)
+    const struct CMUnitTest tests[] = {
+        #define unit_test_make(name) cmocka_unit_test_setup_teardown(name, setup, teardown)
 
         unit_test_make(test_wcore_config_attrs_null_attrib_list),
         unit_test_make(test_wcore_config_attrs_empty_attrib_list),
@@ -1169,14 +1115,10 @@ main(void) {
         unit_test_make(test_wcore_config_attrs_negative_minor_version),
         unit_test_make(test_wcore_config_attrs_gles10),
         unit_test_make(test_wcore_config_attrs_gles11),
-        unit_test_make(test_wcore_config_attrs_gles12_is_bad),
         unit_test_make(test_wcore_config_attrs_gles20),
         unit_test_make(test_wcore_config_attrs_gles21),
-        unit_test_make(test_wcore_config_attrs_gles2_with_version_30),
         unit_test_make(test_wcore_config_attrs_gles30),
         unit_test_make(test_wcore_config_attrs_gles31),
-        unit_test_make(test_wcore_config_attrs_gles3_with_version_20),
-        unit_test_make(test_wcore_config_attrs_gles3_with_version_40),
         unit_test_make(test_wcore_config_attrs_color_buffer_size),
         unit_test_make(test_wcore_config_attrs_double_buffered_is_true),
         unit_test_make(test_wcore_config_attrs_double_buffered_is_false),
@@ -1213,5 +1155,5 @@ main(void) {
         #undef unit_test_make
     };
 
-    return run_tests(tests);
+    return cmocka_run_group_tests(tests, NULL, NULL);
 }
