@@ -67,6 +67,18 @@ check_context_attrs(struct wegl_display *dpy,
         return false;
     }
 
+    if (attrs->lose_context_on_reset) {
+        if (dpy->major_version <= 1 && dpy->minor_version < 5 &&
+            !dpy->KHR_create_context && !dpy->EXT_create_context_robustness) {
+            wcore_errorf(
+                WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
+                "EGL 1.5, EXT_create_context_robustness, or "
+                "EGL_KHR_create_context is required in order to enable "
+                "reset notification");
+            return false;
+        }
+    }
+
     switch (attrs->context_api) {
         case WAFFLE_CONTEXT_OPENGL:
             if (!(dpy->api_mask & WEGL_OPENGL_API)) {
