@@ -27,21 +27,22 @@
 
 #include <stdbool.h>
 
-#include "wegl_window.h"
+#include "wegl_surface.h"
 
 struct wcore_platform;
 struct gbm_surface;
 
 struct wgbm_window {
     struct gbm_surface *gbm_surface;
-    struct wegl_window wegl;
+    struct wegl_surface wegl;
+    struct wcore_config *wc_config;
 };
 
 static inline struct wgbm_window*
 wgbm_window(struct wcore_window *wc_self)
 {
     if (wc_self) {
-        struct wegl_window *wegl_self = container_of(wc_self, struct wegl_window, wcore);
+        struct wegl_surface *wegl_self = container_of(wc_self, struct wegl_surface, wcore);
         return container_of(wegl_self, struct wgbm_window, wegl);
     }
     else {
@@ -52,8 +53,9 @@ wgbm_window(struct wcore_window *wc_self)
 struct wcore_window*
 wgbm_window_create(struct wcore_platform *wc_plat,
                    struct wcore_config *wc_config,
-                   int width,
-                   int height);
+                   int32_t width,
+                   int32_t height,
+                   const intptr_t attrib_list[]);
 
 bool
 wgbm_window_destroy(struct wcore_window *wc_self);
@@ -64,5 +66,9 @@ wgbm_window_show(struct wcore_window *wc_self);
 bool
 wgbm_window_swap_buffers(struct wcore_window *wc_self);
 
+bool
+wgbm_window_resize(struct wcore_window *wc_self,
+                   int32_t width, int32_t height);
+
 union waffle_native_window*
 wgbm_window_get_native(struct wcore_window *wc_self);
