@@ -155,6 +155,11 @@ glx_context_fill_attrib_list(struct glx_config *config,
         context_flags |= GLX_CONTEXT_ROBUST_ACCESS_BIT_ARB;
     }
 
+    if (attrs->lose_context_on_reset) {
+        attrib_list[i++] = GLX_CONTEXT_RESET_NOTIFICATION_STRATEGY_ARB;
+        attrib_list[i++] = GLX_LOSE_CONTEXT_ON_RESET_ARB;
+    }
+
     if (context_flags != 0) {
         attrib_list[i++] = GLX_CONTEXT_FLAGS_ARB;
         attrib_list[i++] = context_flags;
