@@ -56,3 +56,6 @@ sl_window_show(struct wcore_window *wc_self);
 bool
 sl_window_resize(struct wcore_window *wc_self,
                  int32_t width, int32_t height);
+
+union waffle_native_window *
+sl_window_get_native(struct wcore_window *wc_self);
