@@ -23,8 +23,6 @@
 // OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#define _POSIX_C_SOURCE 200112 // glib feature macro for unsetenv()
-
 #include <stdlib.h>
 
 #include "wcore_error.h"
@@ -51,8 +49,6 @@ xegl_platform_destroy(struct wcore_platform *wc_self)
     if (!self)
         return true;
 
-    unsetenv("EGL_PLATFORM");
-
     if (self->linux)
         ok &= linux_platform_destroy(self->linux);
 
@@ -71,7 +67,7 @@ xegl_platform_create(void)
     if (self == NULL)
         return NULL;
 
-    ok = wegl_platform_init(&self->wegl);
+    ok = wegl_platform_init(&self->wegl, EGL_PLATFORM_X11_KHR);
     if (!ok)
         goto error;
 
@@ -79,8 +75,6 @@ xegl_platform_create(void)
     if (!self->linux)
         goto error;
 
-    setenv("EGL_PLATFORM", "x11", true);
-
     self->wegl.wcore.vtbl = &xegl_platform_vtbl;
     return &self->wegl.wcore;
 
@@ -172,7 +166,7 @@ static const struct wcore_platform_vtbl xegl_platform_vtbl = {
         .destroy = xegl_window_destroy,
         .show = xegl_window_show,
         .resize = xegl_window_resize,
-        .swap_buffers = wegl_window_swap_buffers,
+        .swap_buffers = wegl_surface_swap_buffers,
         .get_native = xegl_window_get_native,
     },
 };
